@@ -14,10 +14,13 @@
 #    under the License.
 
 from tempest.api.identity import base
+from tempest import config
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
 from tempest.lib import exceptions as lib_exc
 
+CONF = config.CONF
+
 
 class RolesNegativeTestJSON(base.BaseIdentityV2AdminTest):
     """Negative tests of keystone roles via v2 API"""
@@ -55,7 +58,8 @@ class RolesNegativeTestJSON(base.BaseIdentityV2AdminTest):
     @decorators.idempotent_id('585c8998-a8a4-4641-a5dd-abef7a8ced00')
     def test_create_role_by_unauthorized_user(self):
         """Test non-admin user should not be able to create role via v2 API"""
-        role_name = data_utils.rand_name(name='role')
+        role_name = data_utils.rand_name(
+            name='role', prefix=CONF.resource_name_prefix)
         self.assertRaises(lib_exc.Forbidden,
                           self.non_admin_roles_client.create_role,
                           name=role_name)
@@ -66,7 +70,8 @@ class RolesNegativeTestJSON(base.BaseIdentityV2AdminTest):
         """Test creating role without a valid token via v2 API should fail"""
         token = self.client.auth_provider.get_token()
         self.client.delete_token(token)
-        role_name = data_utils.rand_name(name='role')
+        role_name = data_utils.rand_name(
+            name='role', prefix=CONF.resource_name_prefix)
         self.assertRaises(lib_exc.Unauthorized,
                           self.roles_client.create_role, name=role_name)
         self.client.auth_provider.clear_auth()
@@ -75,7 +80,8 @@ class RolesNegativeTestJSON(base.BaseIdentityV2AdminTest):
     @decorators.idempotent_id('c0cde2c8-81c1-4bb0-8fe2-cf615a3547a8')
     def test_role_create_duplicate(self):
         """Test role names should be unique via v2 API"""
-        role_name = data_utils.rand_name(name='role-dup')
+        role_name = data_utils.rand_name(
+            name='role-dup', prefix=CONF.resource_name_prefix)
         body = self.roles_client.create_role(name=role_name)['role']
         role1_id = body.get('id')
         self.addCleanup(self.roles_client.delete_role, role1_id)
@@ -86,7 +92,8 @@ class RolesNegativeTestJSON(base.BaseIdentityV2AdminTest):
     @decorators.idempotent_id('15347635-b5b1-4a87-a280-deb2bd6d865e')
     def test_delete_role_by_unauthorized_user(self):
         """Test non-admin user should not be able to delete role via v2 API"""
-        role_name = data_utils.rand_name(name='role')
+        role_name = data_utils.rand_name(
+            name='role', prefix=CONF.resource_name_prefix)
         body = self.roles_client.create_role(name=role_name)['role']
         self.addCleanup(self.roles_client.delete_role, body['id'])
         role_id = body.get('id')
@@ -97,7 +104,8 @@ class RolesNegativeTestJSON(base.BaseIdentityV2AdminTest):
     @decorators.idempotent_id('44b60b20-70de-4dac-beaf-a3fc2650a16b')
     def test_delete_role_request_without_token(self):
         """Test deleting role without a valid token via v2 API should fail"""
-        role_name = data_utils.rand_name(name='role')
+        role_name = data_utils.rand_name(
+            name='role', prefix=CONF.resource_name_prefix)
         body = self.roles_client.create_role(name=role_name)['role']
         self.addCleanup(self.roles_client.delete_role, body['id'])
         role_id = body.get('id')
