@@ -196,7 +196,8 @@ def create_test_server(clients, validatable=False, validation_resources=None,
     """
 
     if name is None:
-        name = data_utils.rand_name(__name__ + "-instance")
+        name = data_utils.rand_name(
+            prefix=CONF.resource_name_prefix, name=__name__ + "-instance")
     if flavor is None:
         flavor = CONF.compute.flavor_ref
     if image_id is None:
@@ -245,7 +246,8 @@ def create_test_server(clients, validatable=False, validation_resources=None,
             kwargs['user_data'] = script_b64
 
     if volume_backed:
-        volume_name = data_utils.rand_name(__name__ + '-volume')
+        volume_name = data_utils.rand_name(
+            prefix=CONF.resource_name_prefix, name=__name__ + '-volume')
         volumes_client = clients.volumes_client_latest
         params = {'name': volume_name,
                   'imageRef': image_id,
@@ -375,19 +377,22 @@ def shelve_server(servers_client, server_id, force_shelve_offload=False):
                                  is configured not to offload server
                                  automatically after offload time.
     """
-    servers_client.shelve_server(server_id)
+    body = servers_client.shelve_server(server_id)
+    request_id = body.response['x-openstack-request-id']
 
     offload_time = CONF.compute.shelved_offload_time
     if offload_time >= 0:
         waiters.wait_for_server_status(servers_client, server_id,
                                        'SHELVED_OFFLOADED',
-                                       extra_timeout=offload_time)
+                                       extra_timeout=offload_time,
+                                       request_id=request_id)
     else:
         waiters.wait_for_server_status(servers_client, server_id, 'SHELVED')
         if force_shelve_offload:
             servers_client.shelve_offload_server(server_id)
             waiters.wait_for_server_status(servers_client, server_id,
-                                           'SHELVED_OFFLOADED')
+                                           'SHELVED_OFFLOADED',
+                                           request_id=request_id)
 
 
 def create_websocket(url):
